createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
CreateMessagesRequest createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
CreateMessagesRequest createEmptyInstance() => create();