Vascular class

Constructors

Vascular(String _apiKey, String _userId, List<Language> _languages)

Properties

channel → ClientChannel
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

AddTags(List<String> tags) Future<String>
CreateUser({String userId = ""}) Future<CreateUserReply>
DeleteMessage(String messageId) Future<String>
DeleteTags(List<String> tags) Future<String>
GetMessage(Map<String, MessageData> message) MessageData
GetMessageById(String messagesId) Future<InboxMessage>
GetUser({String userId = ""}) Future<GetUserReply>
Inbox() Future<GetInboxMessagesReply>
InboxNext() Future<GetInboxMessagesReply?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
OpenMessages(List<String> messagesIds) Future<String>
ReadMessages(List<String> messagesIds) Future<String>
Tags() Future<List<TagData>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited